package bank.app;

import java.io.IOException;

import bank.Bank;
import bank.app.bank.Menu;
import pt.tecnico.uilib.Dialog;

/**
 * Bank application.
 */
public class App {

  /** @param args */
  public static void main(String[] args) {
    try (var ui = Dialog.UI) {
      Bank bank = null;
      String saveFilename = System.getProperty("save");
      String importFilename = System.getProperty("import");

      /* Create a Bank instance */
      if (args.length == 1) {
        bank = new Bank(args[0]);
      } else {
        if (saveFilename != null) {
          try {
            bank = Bank.load(saveFilename);
          } catch (IOException | ClassNotFoundException e) {
            System.err.println("Erro: " + saveFilename + " : " + e);
          }
        }
        if (bank == null)
          bank = new Bank("Banco");
      }

      /* Read an import file, if any, and add contents to the bank */
      if (importFilename != null)
        bank.importFile(importFilename);

      /* Start the user interface with the Bank instance */
      // DAVID FIXME TODO UI.setTitle(bank.getName());
      Menu m = new Menu(bank);
      m.open();

      /* On exit, save file. */
      try {
        if (saveFilename != null)
          bank.save(saveFilename);
      } catch (IOException e) {
        System.err.println("Erro: " + saveFilename + " : " + e);
      }
    }
  }

}
