package bank.app.account;

import bank.Account;
import bank.app.exceptions.InvalidWithdrawalUIException;
import bank.app.exceptions.NegativeDepositUIException;
import bank.app.exceptions.NoBalanceWithdrawalUIException;
import bank.exceptions.BalanceTooLowException;
import bank.exceptions.InvalidWithdrawalException;
import bank.exceptions.NegativeAmountException;
import pt.tecnico.uilib.menus.Command;
import pt.tecnico.uilib.menus.CommandException;

/**
 * Command for creating savings accounts.
 */
public class DoCreateSavingsAccount extends Command<Account> {

  /** @param receiver */
  public DoCreateSavingsAccount(Account receiver) {
    super(Labels.CREATE_SAVINGS_ACCOUNT, receiver);
    addRealField("amount", Prompts.requestAmount());
    addRealField("rate", Prompts.requestRate());
    addIntegerField("time", Prompts.requestTime());
  }

  /** @see pt.tecnico.po.uiS.Command#execute() */
  @Override
  protected final void execute() throws CommandException {
    try {
      _receiver.createSavingsAccount(realField("amount"), realField("rate"), integerField("time"));
    } catch (InvalidWithdrawalException e) {
      throw new InvalidWithdrawalUIException(e.getAccount(), e.getAmount());
    } catch (NegativeAmountException e) {
      throw new NegativeDepositUIException(e.getAmount());
    } catch (BalanceTooLowException e) {
      throw new NoBalanceWithdrawalUIException(e.getBalance(), e.getAmount());
    }
  }
}
