package bank.app.account;

import bank.Account;
import bank.app.exceptions.InvalidWithdrawalUIException;
import bank.app.exceptions.NegativeWithdrawalUIException;
import bank.app.exceptions.NoBalanceWithdrawalUIException;
import bank.exceptions.BalanceTooLowException;
import bank.exceptions.InvalidWithdrawalException;
import bank.exceptions.NegativeAmountException;
import pt.tecnico.uilib.menus.Command;
import pt.tecnico.uilib.menus.CommandException;

/**
 * Withdrawal command.
 */
public class DoWithdraw extends Command<Account> {

	/** @param account */
	public DoWithdraw(Account account) {
		super(Labels.WITHDRAW, account);
    addRealField("amount", Prompts.requestAmount());
	}

  /** @see pt.tecnico.po.ui.Command#execute() */
	@Override
	protected final void execute() throws CommandException {
		try {
      _receiver.withdraw(realField("amount"));
    } catch (InvalidWithdrawalException e) {
      throw new InvalidWithdrawalUIException(e.getAccount(), e.getAmount());
    } catch (NegativeAmountException e) {
      throw new NegativeWithdrawalUIException(e.getAmount());
    } catch (BalanceTooLowException e) {
      throw new NoBalanceWithdrawalUIException(e.getBalance(), e.getAmount());
    }
	}
}
